import { ValidatorInternalTest, TestFunction, AltheiaInstance, ValidatorTestResult } from './types';
import { createTest, createTestResult } from './utils/createTest';
/**
 * All type inherit this Class
 */
declare class TypeBase {
    inst: AltheiaInstance;
    tests: (() => ValidatorInternalTest)[];
    name?: string;
    _required: boolean;
    _needCast: boolean;
    _noEmpty?: boolean;
    /**
     * Constructor
     *
     * @param  {Altheia} inst
     */
    constructor(inst?: AltheiaInstance);
    /**
     * Clone this class
     *
     * @return {TypeBase}
     */
    clone<T extends this>(): T;
    /**
     * Add a test
     *
     * @param  {string} name
     * @param  {function} func
     * @param  {Object} args
     * @return {undefined}
     */
    test(name: string, func: TestFunction, args?: {}): void;
    createTest: typeof createTest;
    createTestResult: typeof createTestResult;
    /**
     * Validate a value based on all tests added
     * @param  {mixed}   toTest
     * @param  {Function} callback
     * @return {object}
     */
    validate(toTest: any, callback?: (value: false | ValidatorTestResult) => void): Promise<false | ValidatorTestResult>;
    /**
     * Force the value to be non-null
     *
     * @return {this}
     */
    required(): this;
    /**
     * Force the value to be casted before any check
     *
     * @return {this}
     */
    cast(): this;
    /**
     * Custom validator
     *
     * @param  {string}   name
     * @param  {Function} callback
     * @param  {Function}   message
     * @return {this}
     */
    custom(name: string, callback: TestFunction): this;
    /**
     * Presence validation
     *
     * @param  {mixed} toTest
     * @return {boolean}
     */
    presence(toTest: any): boolean;
    /**
     * If validation
     *
     * @param  {function} options.test
     * @param  {function} options.then
     * @param  {function} options.otherwise
     * @return {this}
     */
    if<T extends this>({ test, then, otherwise, }: {
        test: (chain: T) => TypeBase;
        then: (chain: T) => TypeBase;
        otherwise: (chain: T) => TypeBase;
    }): this;
    private testToTestResult;
}
export default TypeBase;
